summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog7
-rw-r--r--examples/cppunittest/CppUnitTestMain.dsp4
-rw-r--r--examples/cppunittest/TestCallerTest.cpp2
-rw-r--r--examples/cppunittest/TestResultTest.cpp2
-rw-r--r--examples/hierarchy/hierarchy.dsp18
-rw-r--r--examples/msvc6/CppUnitTestApp/CppUnitTestApp.dsp4
-rw-r--r--examples/msvc6/HostApp/ExampleTestCase.cpp2
-rw-r--r--examples/msvc6/HostApp/ExampleTestCase.h14
-rw-r--r--examples/msvc6/HostApp/HostApp.dsp22
-rw-r--r--include/cppunit/extensions/AutoRegisterSuite.h2
-rw-r--r--include/cppunit/extensions/HelperMacros.h90
-rw-r--r--include/cppunit/extensions/TestSuiteBuilder.h8
-rw-r--r--include/cppunit/extensions/TypeInfoHelper.h4
-rw-r--r--src/cppunit/TestCase.cpp4
-rw-r--r--src/cppunit/TestFactoryRegistry.cpp4
-rw-r--r--src/cppunit/TypeInfoHelper.cpp4
-rw-r--r--src/cppunit/cppunit.dsp20
-rw-r--r--src/msvc6/testrunner/TestRunner.dsp22
18 files changed, 120 insertions, 113 deletions
diff --git a/ChangeLog b/ChangeLog
index 8fc9038..6837a3a 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2001-06-02 Steve M. Robbins <steve@nyongwa.montreal.qc.ca>
+
+ * * (CU_TEST_SUITE, CU_TEST, CU_TEST_SUITE_END,
+ CU_TEST_SUITE_REGISTRATION): Replace prefix CU_ with CPPUNIT_.
+
+ * examples/cppunittest/.cvsignore: Add UNIX generated files.
+
2001-06-01 Bastiaan Bakker <bastiaan.bakker@lifeline.nl>
* examples/cppunittest/Makefile.am: added
* configure.in: added examples/cppunittest/Makefile to AC_OUTPUT.
diff --git a/examples/cppunittest/CppUnitTestMain.dsp b/examples/cppunittest/CppUnitTestMain.dsp
index 7b34a1a..f7423f8 100644
--- a/examples/cppunittest/CppUnitTestMain.dsp
+++ b/examples/cppunittest/CppUnitTestMain.dsp
@@ -42,7 +42,7 @@ RSC=rc.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MT /W3 /GR /GX /O2 /I "../../include" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /D "CU_USE_TYPEINFO" /FD /c
+# ADD CPP /nologo /MT /W3 /GR /GX /O2 /I "../../include" /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /D "CPPUNIT_USE_TYPEINFO" /FD /c
# SUBTRACT CPP /YX /Yc /Yu
# ADD BASE RSC /l 0x40c /d "NDEBUG"
# ADD RSC /l 0x40c /d "NDEBUG"
@@ -67,7 +67,7 @@ LINK32=link.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /Yu"stdafx.h" /FD /GZ /c
-# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "../../include" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /D "CU_USE_TYPEINFO" /FD /GZ /c
+# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "../../include" /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /D "CPPUNIT_USE_TYPEINFO" /FD /GZ /c
# SUBTRACT CPP /YX /Yc /Yu
# ADD BASE RSC /l 0x40c /d "_DEBUG"
# ADD RSC /l 0x40c /d "_DEBUG"
diff --git a/examples/cppunittest/TestCallerTest.cpp b/examples/cppunittest/TestCallerTest.cpp
index 9512e02..43cd39f 100644
--- a/examples/cppunittest/TestCallerTest.cpp
+++ b/examples/cppunittest/TestCallerTest.cpp
@@ -2,7 +2,7 @@
#include <cppunit/extensions/TestSuiteBuilder.h>
#include <cppunit/extensions/HelperMacros.h>
-CU_TEST_SUITE_REGISTRATION( TestCallerTest );
+CPPUNIT_TEST_SUITE_REGISTRATION( TestCallerTest );
TestCallerTest::TestCallerTest() :
diff --git a/examples/cppunittest/TestResultTest.cpp b/examples/cppunittest/TestResultTest.cpp
index 7f3f32e..85964f6 100644
--- a/examples/cppunittest/TestResultTest.cpp
+++ b/examples/cppunittest/TestResultTest.cpp
@@ -4,7 +4,7 @@
#include <cppunit/TestResult.h>
#include "MockTestListener.h"
-CU_TEST_SUITE_REGISTRATION( TestResultTest );
+CPPUNIT_TEST_SUITE_REGISTRATION( TestResultTest );
TestResultTest::TestResultTest() :
diff --git a/examples/hierarchy/hierarchy.dsp b/examples/hierarchy/hierarchy.dsp
index 179f638..5659428 100644
--- a/examples/hierarchy/hierarchy.dsp
+++ b/examples/hierarchy/hierarchy.dsp
@@ -4,7 +4,7 @@
# TARGTYPE "Win32 (x86) Console Application" 0x0103
-CFG=hierarchy - Win32 Debug Without CU_USE_TYPEINFO
+CFG=hierarchy - Win32 Debug Without CPPUNIT_USE_TYPEINFO
!MESSAGE This is not a valid makefile. To build this project using NMAKE,
!MESSAGE use the Export Makefile command and run
!MESSAGE
@@ -13,13 +13,13 @@ CFG=hierarchy - Win32 Debug Without CU_USE_TYPEINFO
!MESSAGE You can specify a configuration when running NMAKE
!MESSAGE by defining the macro CFG on the command line. For example:
!MESSAGE
-!MESSAGE NMAKE /f "hierarchy.mak" CFG="hierarchy - Win32 Debug Without CU_USE_TYPEINFO"
+!MESSAGE NMAKE /f "hierarchy.mak" CFG="hierarchy - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
!MESSAGE
!MESSAGE Possible choices for configuration are:
!MESSAGE
!MESSAGE "hierarchy - Win32 Release" (based on "Win32 (x86) Console Application")
!MESSAGE "hierarchy - Win32 Debug" (based on "Win32 (x86) Console Application")
-!MESSAGE "hierarchy - Win32 Debug Without CU_USE_TYPEINFO" (based on "Win32 (x86) Console Application")
+!MESSAGE "hierarchy - Win32 Debug Without CPPUNIT_USE_TYPEINFO" (based on "Win32 (x86) Console Application")
!MESSAGE
# Begin Project
@@ -42,7 +42,7 @@ RSC=rc.exe
# PROP Intermediate_Dir "Release"
# PROP Target_Dir ""
# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_CONSOLE" /D "_MBCS" /YX /FD /c
-# ADD CPP /nologo /W3 /GX /O2 /D "NDEBUG" /D "WIN32" /D "_CONSOLE" /D "_MBCS" /D "CU_USE_TYPEINFO" /YX /FD /c
+# ADD CPP /nologo /W3 /GX /O2 /D "NDEBUG" /D "WIN32" /D "_CONSOLE" /D "_MBCS" /D "CPPUNIT_USE_TYPEINFO" /YX /FD /c
# ADD BASE RSC /l 0x40c /d "NDEBUG"
# ADD RSC /l 0x40c /d "NDEBUG"
BSC32=bscmake.exe
@@ -66,7 +66,7 @@ LINK32=link.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_CONSOLE" /D "_MBCS" /YX /FD /GZ /c
-# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "WIN32" /D "_CONSOLE" /D "_MBCS" /D "CU_USE_TYPEINFO" /YX /FD /GZ /c
+# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "WIN32" /D "_CONSOLE" /D "_MBCS" /D "CPPUNIT_USE_TYPEINFO" /YX /FD /GZ /c
# ADD BASE RSC /l 0x40c /d "_DEBUG"
# ADD RSC /l 0x40c /d "_DEBUG"
BSC32=bscmake.exe
@@ -76,12 +76,12 @@ LINK32=link.exe
# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib ..\..\lib\cppunitd.lib /nologo /subsystem:console /debug /machine:I386 /pdbtype:sept
-!ELSEIF "$(CFG)" == "hierarchy - Win32 Debug Without CU_USE_TYPEINFO"
+!ELSEIF "$(CFG)" == "hierarchy - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# PROP BASE Use_MFC 0
# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "hierarchy___Win32_Debug_Without_CU_USE_TYPEINFO"
-# PROP BASE Intermediate_Dir "hierarchy___Win32_Debug_Without_CU_USE_TYPEINFO"
+# PROP BASE Output_Dir "hierarchy___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
+# PROP BASE Intermediate_Dir "hierarchy___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
# PROP BASE Ignore_Export_Lib 0
# PROP BASE Target_Dir ""
# PROP Use_MFC 0
@@ -107,7 +107,7 @@ LINK32=link.exe
# Name "hierarchy - Win32 Release"
# Name "hierarchy - Win32 Debug"
-# Name "hierarchy - Win32 Debug Without CU_USE_TYPEINFO"
+# Name "hierarchy - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# Begin Source File
SOURCE=.\BoardGame.cpp
diff --git a/examples/msvc6/CppUnitTestApp/CppUnitTestApp.dsp b/examples/msvc6/CppUnitTestApp/CppUnitTestApp.dsp
index 409cbd7..6f0ff8a 100644
--- a/examples/msvc6/CppUnitTestApp/CppUnitTestApp.dsp
+++ b/examples/msvc6/CppUnitTestApp/CppUnitTestApp.dsp
@@ -43,7 +43,7 @@ RSC=rc.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MD /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /D "_AFXDLL" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MD /W3 /GR /GX /O2 /D "NDEBUG" /D "WIN32" /D "_WINDOWS" /D "_AFXDLL" /D "_MBCS" /D "CU_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MD /W3 /GR /GX /O2 /D "NDEBUG" /D "WIN32" /D "_WINDOWS" /D "_AFXDLL" /D "_MBCS" /D "CPPUNIT_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /win32
# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /win32
# ADD BASE RSC /l 0x40c /d "NDEBUG" /d "_AFXDLL"
@@ -74,7 +74,7 @@ PostBuild_Cmds=copy ..\..\..\Lib\testrunner.dll Release
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MDd /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /Yu"stdafx.h" /FD /GZ /c
-# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "../../../include" /D "_DEBUG" /D "WIN32" /D "_WINDOWS" /D "_AFXDLL" /D "_MBCS" /D "CU_USE_TYPEINFO" /Yu"stdafx.h" /FD /GZ /c
+# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "../../../include" /D "_DEBUG" /D "WIN32" /D "_WINDOWS" /D "_AFXDLL" /D "_MBCS" /D "CPPUNIT_USE_TYPEINFO" /Yu"stdafx.h" /FD /GZ /c
# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /win32
# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /win32
# ADD BASE RSC /l 0x40c /d "_DEBUG" /d "_AFXDLL"
diff --git a/examples/msvc6/HostApp/ExampleTestCase.cpp b/examples/msvc6/HostApp/ExampleTestCase.cpp
index 98089dd..22818af 100644
--- a/examples/msvc6/HostApp/ExampleTestCase.cpp
+++ b/examples/msvc6/HostApp/ExampleTestCase.cpp
@@ -1,6 +1,6 @@
#include "ExampleTestCase.h"
-CU_TEST_SUITE_REGISTRATION( ExampleTestCase );
+CPPUNIT_TEST_SUITE_REGISTRATION( ExampleTestCase );
void ExampleTestCase::example ()
{
diff --git a/examples/msvc6/HostApp/ExampleTestCase.h b/examples/msvc6/HostApp/ExampleTestCase.h
index 396ec66..7c993ee 100644
--- a/examples/msvc6/HostApp/ExampleTestCase.h
+++ b/examples/msvc6/HostApp/ExampleTestCase.h
@@ -13,13 +13,13 @@
class ExampleTestCase : public CppUnit::TestCase
{
- CU_TEST_SUITE( ExampleTestCase );
- CU_TEST( example );
- CU_TEST( anotherExample );
- CU_TEST( testAdd );
- CU_TEST( testDivideByZero );
- CU_TEST( testEquals );
- CU_TEST_SUITE_END();
+ CPPUNIT_TEST_SUITE( ExampleTestCase );
+ CPPUNIT_TEST( example );
+ CPPUNIT_TEST( anotherExample );
+ CPPUNIT_TEST( testAdd );
+ CPPUNIT_TEST( testDivideByZero );
+ CPPUNIT_TEST( testEquals );
+ CPPUNIT_TEST_SUITE_END();
protected:
double m_value1;
diff --git a/examples/msvc6/HostApp/HostApp.dsp b/examples/msvc6/HostApp/HostApp.dsp
index c04ae7c..5883f7c 100644
--- a/examples/msvc6/HostApp/HostApp.dsp
+++ b/examples/msvc6/HostApp/HostApp.dsp
@@ -4,7 +4,7 @@
# TARGTYPE "Win32 (x86) Application" 0x0101
-CFG=HostApp - Win32 Debug Without CU_USE_TYPEINFO
+CFG=HostApp - Win32 Debug Without CPPUNIT_USE_TYPEINFO
!MESSAGE This is not a valid makefile. To build this project using NMAKE,
!MESSAGE use the Export Makefile command and run
!MESSAGE
@@ -13,13 +13,13 @@ CFG=HostApp - Win32 Debug Without CU_USE_TYPEINFO
!MESSAGE You can specify a configuration when running NMAKE
!MESSAGE by defining the macro CFG on the command line. For example:
!MESSAGE
-!MESSAGE NMAKE /f "HostApp.mak" CFG="HostApp - Win32 Debug Without CU_USE_TYPEINFO"
+!MESSAGE NMAKE /f "HostApp.mak" CFG="HostApp - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
!MESSAGE
!MESSAGE Possible choices for configuration are:
!MESSAGE
!MESSAGE "HostApp - Win32 Release" (based on "Win32 (x86) Application")
!MESSAGE "HostApp - Win32 Debug" (based on "Win32 (x86) Application")
-!MESSAGE "HostApp - Win32 Debug Without CU_USE_TYPEINFO" (based on "Win32 (x86) Application")
+!MESSAGE "HostApp - Win32 Debug Without CPPUNIT_USE_TYPEINFO" (based on "Win32 (x86) Application")
!MESSAGE
# Begin Project
@@ -43,7 +43,7 @@ RSC=rc.exe
# PROP Intermediate_Dir "Release"
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MD /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /D "_AFXDLL" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /D "NDEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /D "CU_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /D "NDEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /D "CPPUNIT_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /o "NUL" /win32
# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /o "NUL" /win32
# ADD BASE RSC /l 0x409 /d "NDEBUG" /d "_AFXDLL"
@@ -69,7 +69,7 @@ LINK32=link.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MDd /W3 /Gm /GX /Zi /Od /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /D "CU_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /D "CPPUNIT_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
# ADD BASE RSC /l 0x409 /d "_DEBUG" /d "_AFXDLL"
@@ -86,12 +86,12 @@ SOURCE="$(InputPath)"
PreLink_Cmds=copy ..\..\..\lib\testrunnerd.dll Debug
# End Special Build Tool
-!ELSEIF "$(CFG)" == "HostApp - Win32 Debug Without CU_USE_TYPEINFO"
+!ELSEIF "$(CFG)" == "HostApp - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# PROP BASE Use_MFC 6
# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "HostApp___Win32_Debug_Without_CU_USE_TYPEINFO"
-# PROP BASE Intermediate_Dir "HostApp___Win32_Debug_Without_CU_USE_TYPEINFO"
+# PROP BASE Output_Dir "HostApp___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
+# PROP BASE Intermediate_Dir "HostApp___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
# PROP BASE Ignore_Export_Lib 0
# PROP BASE Target_Dir ""
# PROP Use_MFC 6
@@ -100,7 +100,7 @@ PreLink_Cmds=copy ..\..\..\lib\testrunnerd.dll Debug
# PROP Intermediate_Dir "DebugNoTypeInfo"
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
-# ADD BASE CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /D "CU_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
+# ADD BASE CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /D "CPPUNIT_USE_TYPEINFO" /Yu"stdafx.h" /FD /c
# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_AFXDLL" /D "WIN32" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
@@ -125,7 +125,7 @@ PreLink_Cmds=copy ..\..\..\lib\testrunnernotypeinfod.dll DebugNoTypeInfo
# Name "HostApp - Win32 Release"
# Name "HostApp - Win32 Debug"
-# Name "HostApp - Win32 Debug Without CU_USE_TYPEINFO"
+# Name "HostApp - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# Begin Group "Source Files"
# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
@@ -139,7 +139,7 @@ SOURCE=.\ExampleTestCase.cpp
# SUBTRACT CPP /YX /Yc /Yu
-!ELSEIF "$(CFG)" == "HostApp - Win32 Debug Without CU_USE_TYPEINFO"
+!ELSEIF "$(CFG)" == "HostApp - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# SUBTRACT BASE CPP /YX /Yc /Yu
# SUBTRACT CPP /YX /Yc /Yu
diff --git a/include/cppunit/extensions/AutoRegisterSuite.h b/include/cppunit/extensions/AutoRegisterSuite.h
index cec56c0..7033412 100644
--- a/include/cppunit/extensions/AutoRegisterSuite.h
+++ b/include/cppunit/extensions/AutoRegisterSuite.h
@@ -15,7 +15,7 @@ namespace CppUnit {
* This object is intented to be used as a static variable.
*
* \param TestCaseType Type of the test case which suite is registered.
- * \see CU_TEST_SUITE_REGISTRATION.
+ * \see CPPUNIT_TEST_SUITE_REGISTRATION.
*/
template<typename TestCaseType>
class AutoRegisterSuite
diff --git a/include/cppunit/extensions/TestSuiteBuilder.h b/include/cppunit/extensions/TestSuiteBuilder.h
index 11b86fb..c1c6906 100644
--- a/include/cppunit/extensions/TestSuiteBuilder.h
+++ b/include/cppunit/extensions/TestSuiteBuilder.h
@@ -5,9 +5,9 @@
#include <cppunit/TestSuite.h>
#include <cppunit/TestCaller.h>
-#ifdef CU_USE_TYPEINFO
+#ifdef CPPUNIT_USE_TYPEINFO
#include <cppunit/extensions/TypeInfoHelper.h>
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
namespace CppUnit {
@@ -17,13 +17,13 @@ namespace CppUnit {
public:
typedef void (Fixture::*TestMethod)();
-#ifdef CU_USE_TYPEINFO
+#ifdef CPPUNIT_USE_TYPEINFO
TestSuiteBuilder() :
m_suite( new TestSuite(
TypeInfoHelper::getClassName( typeid(Fixture) ) ) )
{
}
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
TestSuiteBuilder( TestSuite *suite ) : m_suite( suite )
{
diff --git a/include/cppunit/extensions/TypeInfoHelper.h b/include/cppunit/extensions/TypeInfoHelper.h
index 8ce5b16..6dd6ae8 100644
--- a/include/cppunit/extensions/TypeInfoHelper.h
+++ b/include/cppunit/extensions/TypeInfoHelper.h
@@ -1,7 +1,7 @@
#ifndef CPPUNIT_TYPEINFOHELPER_H
#define CPPUNIT_TYPEINFOHELPER_H
-#ifdef CU_USE_TYPEINFO
+#ifdef CPPUNIT_USE_TYPEINFO
#include <typeinfo>
@@ -24,6 +24,6 @@ namespace CppUnit {
} // namespace CppUnit
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
#endif // CPPUNIT_TYPEINFOHELPER_H
diff --git a/src/cppunit/TestCase.cpp b/src/cppunit/TestCase.cpp
index 1b623c9..d48531c 100644
--- a/src/cppunit/TestCase.cpp
+++ b/src/cppunit/TestCase.cpp
@@ -115,12 +115,12 @@ std::string
{
std::string className;
-#ifdef CU_USE_TYPEINFO
+#ifdef CPPUNIT_USE_TYPEINFO
const std::type_info& thisClass = typeid (*this);
className = thisClass.name();
#else
className = "TestCase";
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
return className + "." + getName ();
}
diff --git a/src/cppunit/TestFactoryRegistry.cpp b/src/cppunit/TestFactoryRegistry.cpp
index c9b1096..8d44312 100644
--- a/src/cppunit/TestFactoryRegistry.cpp
+++ b/src/cppunit/TestFactoryRegistry.cpp
@@ -8,9 +8,9 @@
#include "cppunit/TestSuite.h"
#include "cppunit/extensions/TestFactoryRegistry.h"
-#ifdef CU_USE_TYPEINFO
+#ifdef CPPUNIT_USE_TYPEINFO
#include "cppunit/extensions/TypeInfoHelper.h"
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
namespace CppUnit {
diff --git a/src/cppunit/TypeInfoHelper.cpp b/src/cppunit/TypeInfoHelper.cpp
index abea261..108484d 100644
--- a/src/cppunit/TypeInfoHelper.cpp
+++ b/src/cppunit/TypeInfoHelper.cpp
@@ -1,4 +1,4 @@
-#ifdef CU_USE_TYPEINFO
+#ifdef CPPUNIT_USE_TYPEINFO
#include <string>
#include <cppunit/extensions/TypeInfoHelper.h>
@@ -20,4 +20,4 @@ TypeInfoHelper::getClassName( const std::type_info &info )
} // namespace CppUnit
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
diff --git a/src/cppunit/cppunit.dsp b/src/cppunit/cppunit.dsp
index 7538d25..00cfd34 100644
--- a/src/cppunit/cppunit.dsp
+++ b/src/cppunit/cppunit.dsp
@@ -4,7 +4,7 @@
# TARGTYPE "Win32 (x86) Static Library" 0x0104
-CFG=cppunit - Win32 Debug Without CU_USE_TYPEINFO
+CFG=cppunit - Win32 Debug Without CPPUNIT_USE_TYPEINFO
!MESSAGE This is not a valid makefile. To build this project using NMAKE,
!MESSAGE use the Export Makefile command and run
!MESSAGE
@@ -13,13 +13,13 @@ CFG=cppunit - Win32 Debug Without CU_USE_TYPEINFO
!MESSAGE You can specify a configuration when running NMAKE
!MESSAGE by defining the macro CFG on the command line. For example:
!MESSAGE
-!MESSAGE NMAKE /f "cppunit.mak" CFG="cppunit - Win32 Debug Without CU_USE_TYPEINFO"
+!MESSAGE NMAKE /f "cppunit.mak" CFG="cppunit - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
!MESSAGE
!MESSAGE Possible choices for configuration are:
!MESSAGE
!MESSAGE "cppunit - Win32 Release" (based on "Win32 (x86) Static Library")
!MESSAGE "cppunit - Win32 Debug" (based on "Win32 (x86) Static Library")
-!MESSAGE "cppunit - Win32 Debug Without CU_USE_TYPEINFO" (based on "Win32 (x86) Static Library")
+!MESSAGE "cppunit - Win32 Debug Without CPPUNIT_USE_TYPEINFO" (based on "Win32 (x86) Static Library")
!MESSAGE
# Begin Project
@@ -42,7 +42,7 @@ RSC=rc.exe
# PROP Intermediate_Dir "Release"
# PROP Target_Dir ""
# ADD BASE CPP /nologo /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_MBCS" /D "_LIB" /YX /FD /c
-# ADD CPP /nologo /MT /W3 /GR /GX /O2 /I "..\..\include" /D "NDEBUG" /D "_MBCS" /D "_LIB" /D "CU_USE_TYPEINFO" /D "WIN32" /YX /FD /c
+# ADD CPP /nologo /MT /W3 /GR /GX /O2 /I "..\..\include" /D "NDEBUG" /D "_MBCS" /D "_LIB" /D "CPPUNIT_USE_TYPEINFO" /D "WIN32" /YX /FD /c
# ADD BASE RSC /l 0x40c /d "NDEBUG"
# ADD RSC /l 0x40c /d "NDEBUG"
BSC32=bscmake.exe
@@ -65,7 +65,7 @@ LIB32=link.exe -lib
# PROP Intermediate_Dir "Debug"
# PROP Target_Dir ""
# ADD BASE CPP /nologo /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_MBCS" /D "_LIB" /YX /FD /GZ /c
-# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "_MBCS" /D "_LIB" /D "CU_USE_TYPEINFO" /D "WIN32" /YX /FD /GZ /c
+# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "_MBCS" /D "_LIB" /D "CPPUNIT_USE_TYPEINFO" /D "WIN32" /YX /FD /GZ /c
# ADD BASE RSC /l 0x40c /d "_DEBUG"
# ADD RSC /l 0x40c /d "_DEBUG"
BSC32=bscmake.exe
@@ -75,19 +75,19 @@ LIB32=link.exe -lib
# ADD BASE LIB32 /nologo
# ADD LIB32 /nologo /out:"..\..\lib\cppunitd.lib"
-!ELSEIF "$(CFG)" == "cppunit - Win32 Debug Without CU_USE_TYPEINFO"
+!ELSEIF "$(CFG)" == "cppunit - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# PROP BASE Use_MFC 0
# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "cppunit___Win32_Debug_Without_CU_USE_TYPEINFO"
-# PROP BASE Intermediate_Dir "cppunit___Win32_Debug_Without_CU_USE_TYPEINFO"
+# PROP BASE Output_Dir "cppunit___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
+# PROP BASE Intermediate_Dir "cppunit___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
# PROP BASE Target_Dir ""
# PROP Use_MFC 0
# PROP Use_Debug_Libraries 1
# PROP Output_Dir "DebugNoTypeInfo"
# PROP Intermediate_Dir "DebugNoTypeInfo"
# PROP Target_Dir ""
-# ADD BASE CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "_MBCS" /D "_LIB" /D "CU_USE_TYPEINFO" /D "WIN32" /YX /FD /GZ /c
+# ADD BASE CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "_MBCS" /D "_LIB" /D "CPPUNIT_USE_TYPEINFO" /D "WIN32" /YX /FD /GZ /c
# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\include" /D "_DEBUG" /D "_MBCS" /D "_LIB" /D "WIN32" /YX /FD /GZ /c
# ADD BASE RSC /l 0x40c /d "_DEBUG"
# ADD RSC /l 0x40c /d "_DEBUG"
@@ -104,7 +104,7 @@ LIB32=link.exe -lib
# Name "cppunit - Win32 Release"
# Name "cppunit - Win32 Debug"
-# Name "cppunit - Win32 Debug Without CU_USE_TYPEINFO"
+# Name "cppunit - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# Begin Group "extensions"
# PROP Default_Filter ""
diff --git a/src/msvc6/testrunner/TestRunner.dsp b/src/msvc6/testrunner/TestRunner.dsp
index 9842b55..8b360dd 100644
--- a/src/msvc6/testrunner/TestRunner.dsp
+++ b/src/msvc6/testrunner/TestRunner.dsp
@@ -4,7 +4,7 @@
# TARGTYPE "Win32 (x86) Dynamic-Link Library" 0x0102
-CFG=TestRunner - Win32 Debug Without CU_USE_TYPEINFO
+CFG=TestRunner - Win32 Debug Without CPPUNIT_USE_TYPEINFO
!MESSAGE This is not a valid makefile. To build this project using NMAKE,
!MESSAGE use the Export Makefile command and run
!MESSAGE
@@ -13,13 +13,13 @@ CFG=TestRunner - Win32 Debug Without CU_USE_TYPEINFO
!MESSAGE You can specify a configuration when running NMAKE
!MESSAGE by defining the macro CFG on the command line. For example:
!MESSAGE
-!MESSAGE NMAKE /f "TestRunner.mak" CFG="TestRunner - Win32 Debug Without CU_USE_TYPEINFO"
+!MESSAGE NMAKE /f "TestRunner.mak" CFG="TestRunner - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
!MESSAGE
!MESSAGE Possible choices for configuration are:
!MESSAGE
!MESSAGE "TestRunner - Win32 Release" (based on "Win32 (x86) Dynamic-Link Library")
!MESSAGE "TestRunner - Win32 Debug" (based on "Win32 (x86) Dynamic-Link Library")
-!MESSAGE "TestRunner - Win32 Debug Without CU_USE_TYPEINFO" (based on "Win32 (x86) Dynamic-Link Library")
+!MESSAGE "TestRunner - Win32 Debug Without CPPUNIT_USE_TYPEINFO" (based on "Win32 (x86) Dynamic-Link Library")
!MESSAGE
# Begin Project
@@ -43,7 +43,7 @@ RSC=rc.exe
# PROP Intermediate_Dir "Release"
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MD /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /D "NDEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "CU_USE_TYPEINFO" /D "WIN32" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /D "NDEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "CPPUNIT_USE_TYPEINFO" /D "WIN32" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /o "NUL" /win32
# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /o "NUL" /win32
# ADD BASE RSC /l 0x409 /d "NDEBUG" /d "_AFXDLL"
@@ -69,7 +69,7 @@ LINK32=link.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MDd /W3 /Gm /GX /Zi /Od /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /Yu"stdafx.h" /FD /c
-# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "CU_USE_TYPEINFO" /D "WIN32" /Yu"stdafx.h" /FD /c
+# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "CPPUNIT_USE_TYPEINFO" /D "WIN32" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
# ADD BASE RSC /l 0x409 /d "_DEBUG" /d "_AFXDLL"
@@ -82,12 +82,12 @@ LINK32=link.exe
# ADD LINK32 ..\..\..\lib\cppunitd.lib winmm.lib /nologo /subsystem:windows /dll /debug /machine:I386 /out:"..\..\..\lib\testrunnerd.dll" /implib:"..\..\..\lib\testrunnerd.lib" /pdbtype:sept
# SUBTRACT LINK32 /pdb:none
-!ELSEIF "$(CFG)" == "TestRunner - Win32 Debug Without CU_USE_TYPEINFO"
+!ELSEIF "$(CFG)" == "TestRunner - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# PROP BASE Use_MFC 6
# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "TestRunner___Win32_Debug_Without_CU_USE_TYPEINFO"
-# PROP BASE Intermediate_Dir "TestRunner___Win32_Debug_Without_CU_USE_TYPEINFO"
+# PROP BASE Output_Dir "TestRunner___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
+# PROP BASE Intermediate_Dir "TestRunner___Win32_Debug_Without_CPPUNIT_USE_TYPEINFO"
# PROP BASE Ignore_Export_Lib 0
# PROP BASE Target_Dir ""
# PROP Use_MFC 6
@@ -96,7 +96,7 @@ LINK32=link.exe
# PROP Intermediate_Dir "DebugNoTypeInfo"
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
-# ADD BASE CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "CU_USE_TYPEINFO" /D "WIN32" /Yu"stdafx.h" /FD /c
+# ADD BASE CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "CPPUNIT_USE_TYPEINFO" /D "WIN32" /Yu"stdafx.h" /FD /c
# ADD CPP /nologo /MDd /W3 /Gm /GR /GX /ZI /Od /I "..\..\..\include" /I "..\..\..\include\msvc6" /D "_DEBUG" /D "_WINDOWS" /D "_WINDLL" /D "_AFXDLL" /D "_AFXEXT" /D "WIN32" /Yu"stdafx.h" /FD /c
# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o "NUL" /win32
@@ -117,7 +117,7 @@ LINK32=link.exe
# Name "TestRunner - Win32 Release"
# Name "TestRunner - Win32 Debug"
-# Name "TestRunner - Win32 Debug Without CU_USE_TYPEINFO"
+# Name "TestRunner - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# Begin Group "Source Files"
# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
@@ -150,7 +150,7 @@ SOURCE=.\TestRunner.def
!ELSEIF "$(CFG)" == "TestRunner - Win32 Debug"
-!ELSEIF "$(CFG)" == "TestRunner - Win32 Debug Without CU_USE_TYPEINFO"
+!ELSEIF "$(CFG)" == "TestRunner - Win32 Debug Without CPPUNIT_USE_TYPEINFO"
# PROP Exclude_From_Build 1
diff --git a/include/cppunit/extensions/HelperMacros.h b/include/cppunit/extensions/HelperMacros.h
index 5f634d5..12defe8 100644
--- a/include/cppunit/extensions/HelperMacros.h
+++ b/include/cppunit/extensions/HelperMacros.h
@@ -10,37 +10,37 @@
#include <cppunit/extensions/AutoRegisterSuite.h>
#include <cppunit/extensions/TestSuiteBuilder.h>
// The macro __CU_SUITE_CTOR_ARGS expand to an expression used to construct
// the TestSuiteBuilder with macro CU_TEST_SUITE.
//
// The name of the suite is obtained using RTTI if CU_USE_TYPEINFO is
// defined, otherwise it is extracted from the macro parameter
//
// This macro is for cppunit internal and should not be use otherwise.
-#ifdef CU_USE_TYPEINFO
-#define __CU_SUITE_CTOR_ARGS( ATestCaseType )
+#ifdef CPPUNIT_USE_TYPEINFO
+#define __CPPUNIT_SUITE_CTOR_ARGS( ATestCaseType )
-#else // CU_USE_TYPEINFO
-#define __CU_SUITE_CTOR_ARGS( ATestCaseType ) (std::string(#ATestCaseType))
+#else // CPPUNIT_USE_TYPEINFO
+#define __CPPUNIT_SUITE_CTOR_ARGS( ATestCaseType ) (std::string(#ATestCaseType))
-#endif // CU_USE_TYPEINFO
+#endif // CPPUNIT_USE_TYPEINFO
/** \file
* Macros intended to ease the definition of test suites.
*
* The macros
- * CU_TEST_SUITE(), CU_TEST(), and CU_TEST_SUITE_END()
+ * CPPUNIT_TEST_SUITE(), CPPUNIT_TEST(), and CPPUNIT_TEST_SUITE_END()
* are designed to facilitate easy creation of a test suite.
* For example,
*
* \code
* #include <cppunit/extensions/HelperMacros.h>
* class MyTest : public CppUnit::TestCase {
- * CU_TEST_SUITE( MyTest );
- * CU_TEST( testEquality );
- * CU_TEST( testSetName );
- * CU_TEST_SUITE_END();
+ * CPPUNIT_TEST_SUITE( MyTest );
+ * CPPUNIT_TEST( testEquality );
+ * CPPUNIT_TEST( testSetName );
+ * CPPUNIT_TEST_SUITE_END();
* public:
* void testEquality();
* void testSetName();
@@ -52,17 +52,17 @@
* named registerTests that you will not need to call directly.
* The second function
* \code static CppUnit::TestSuite *suite()\endcode
* returns a pointer to the suite of tests defined by the CU_TEST()
* macros.
*
* Rather than invoking suite() directly,
* the macro CU_TEST_SUITE_REGISTRATION() is
* used to create a static variable that automatically
* registers its test suite in a global registry.
* The registry yields a Test instance containing all the
* registered suites.
* \code
- * CU_TEST_SUITE_REGISTRATION( MyTest );
+ * CPPUNIT_TEST_SUITE_REGISTRATION( MyTest );
* CppUnit::Test* tp =
* CppUnit::TestFactoryRegistry::getRegistry().makeTest();
* \endcode
@@ -73,9 +73,9 @@
* \code
* template<typename CharType>
* class StringTest : public CppUnit::Testcase {
- * CU_TEST_SUITE( StringTest );
- * CU_TEST( testAppend );
- * CU_TEST_SUITE_END();
+ * CPPUNIT_TEST_SUITE( StringTest );
+ * CPPUNIT_TEST( testAppend );
+ * CPPUNIT_TEST_SUITE_END();
* public:
* ...
* };
@@ -84,8 +84,8 @@
* You need to add in an implementation file:
*
* \code
- * CU_TEST_SUITE_REGISTRATION( String<char> );
- * CU_TEST_SUITE_REGISTRATION( String<wchar_t> );
+ * CPPUNIT_TEST_SUITE_REGISTRATION( String<char> );
+ * CPPUNIT_TEST_SUITE_REGISTRATION( String<wchar_t> );
* \endcode
*/
@@ -93,13 +93,13 @@
/** Begin test suite
*
* This macro starts the declaration of a new test suite.
* Use CU_TEST_SUB_SUITE() instead, if you wish to include the
* test suite of the parent class.
*
* \param ATestCaseType Type of the test case class.
- * \see CU_TEST_SUB_SUITE, CU_TEST, CU_TEST_SUITE_END, CU_TEST_SUITE_REGISTRATION.
+ * \see CPPUNIT_TEST_SUB_SUITE, CPPUNIT_TEST, CPPUNIT_TEST_SUITE_END, CPPUNIT_TEST_SUITE_REGISTRATION.
*/
-#define CU_TEST_SUITE( ATestCaseType ) \
+#define CPPUNIT_TEST_SUITE( ATestCaseType ) \
private: \
typedef ATestCaseType __ThisTestCaseType; \
public: \
@@ -113,10 +113,10 @@
/** Begin test suite (includes parent suite)
*
* This macro may only be used in a class whose parent class
* defines a test suite using CU_TEST_SUITE() or CU_TEST_SUB_SUITE().
*
* This macro begins the declaration of a test suite, in the same
* manner as CU_TEST_SUITE(). In addition, the test suite of the
* parent is automatically inserted in the test suite being
* defined.
*
@@ -125,10 +125,10 @@
* \code
* #include <cppunit/extensions/HelperMacros.h>
* class MySubTest : public MyTest {
- * CU_TEST_SUB_SUITE( MySubTest, MyTest );
- * CU_TEST( testAdd );
- * CU_TEST( testSub );
- * CU_TEST_SUITE_END();
+ * CPPUNIT_TEST_SUB_SUITE( MySubTest, MyTest );
+ * CPPUNIT_TEST( testAdd );
+ * CPPUNIT_TEST( testSub );
+ * CPPUNIT_TEST_SUITE_END();
* public:
* void testAdd();
* void testSub();
@@ -137,12 +137,12 @@
*
* \param ATestCaseType Type of the test case class.
* \param ASuperClass Type of the parent class.
- * \see CU_TEST_SUITE.
+ * \see CPPUNIT_TEST_SUITE.
*/
-#define CU_TEST_SUB_SUITE( ATestCaseType, ASuperClass ) \
+#define CPPUNIT_TEST_SUB_SUITE( ATestCaseType, ASuperClass ) \
private: \
typedef ASuperClass __ThisSuperClassType; \
- CU_TEST_SUITE( ATestCaseType ); \
+ CPPUNIT_TEST_SUITE( ATestCaseType ); \
__ThisSuperClassType::registerTests( suite, test )
@@ -150,9 +150,9 @@
* \param testMethod Name of the method of the test case to add to the
* suite. The signature of the method must be of
* type: void testMethod();
- * \see CU_TEST_SUITE.
+ * \see CPPUNIT_TEST_SUITE.
*/
-#define CU_TEST( testMethod ) \
+#define CPPUNIT_TEST( testMethod ) \
suite.addTestCaller( #testMethod, &__ThisTestCaseType::testMethod )
@@ -160,28 +160,28 @@
*
* After this macro, member access is set to "private".
*
- * \see CU_TEST_SUITE.
- * \see CU_TEST_SUITE_REGISTRATION.
+ * \see CPPUNIT_TEST_SUITE.
+ * \see CPPUNIT_TEST_SUITE_REGISTRATION.
*/
-#define CU_TEST_SUITE_END() \
+#define CPPUNIT_TEST_SUITE_END() \
} \
static CppUnit::Test *suite() \
{ \
__ThisTestCaseType *test =NULL; \
CppUnit::TestSuiteBuilder<__ThisTestCaseType> \
- suite __CU_SUITE_CTOR_ARGS( ATestCaseType ); \
+ suite __CPPUNIT_SUITE_CTOR_ARGS( ATestCaseType ); \
__ThisTestCaseType::registerTests( suite, test ); \
return suite.takeSuite(); \
} \
private:
-#define __CU_CONCATENATE_DIRECT( s1, s2 ) s1##s2
-#define __CU_CONCATENATE( s1, s2 ) __CU_CONCATENATE_DIRECT( s1, s2 )
+#define __CPPUNIT_CONCATENATE_DIRECT( s1, s2 ) s1##s2
+#define __CPPUNIT_CONCATENATE( s1, s2 ) __CPPUNIT_CONCATENATE_DIRECT( s1, s2 )
/** Decorates the specified string with the line number to obtain a unique name;
* @param str String to decorate.
*/
-#define __CU_MAKE_UNIQUE_NAME( str ) __CU_CONCATENATE( str, __LINE__ )
+#define __CPPUNIT_MAKE_UNIQUE_NAME( str ) __CPPUNIT_CONCATENATE( str, __LINE__ )
/** Register test suite into global registry.
@@ -194,11 +194,11 @@
* \param ATestCaseType Type of the test case class.
* \warning This macro should be used only once per line of code (the line
* number is used to name a hidden static variable).
- * \see CU_TEST_SUITE, CppUnit::AutoRegisterSuite.
+ * \see CPPUNIT_TEST_SUITE, CppUnit::AutoRegisterSuite.
*/
-#define CU_TEST_SUITE_REGISTRATION( ATestCaseType ) \
+#define CPPUNIT_TEST_SUITE_REGISTRATION( ATestCaseType ) \
static CppUnit::AutoRegisterSuite< ATestCaseType > \
- __CU_MAKE_UNIQUE_NAME(__autoRegisterSuite )
+ __CPPUNIT_MAKE_UNIQUE_NAME(__autoRegisterSuite )
#endif // CPPUNIT_EXTENSIONS_HELPERMACROS_H
@@ -10,37 +10,37 @@
#include <cppunit/extensions/AutoRegisterSuite.h>
#include <cppunit/extensions/TestSuiteBuilder.h>
-// The macro __CU_SUITE_CTOR_ARGS expand to an expression used to construct
-// the TestSuiteBuilder with macro CU_TEST_SUITE.
+// The macro __CPPUNIT_SUITE_CTOR_ARGS expand to an expression used to construct
+// the TestSuiteBuilder with macro CPPUNIT_TEST_SUITE.
//
@@ -10,37 +10,37 @@
//
-// The name of the suite is obtained using RTTI if CU_USE_TYPEINFO is
+// The name of the suite is obtained using RTTI if CPPUNIT_USE_TYPEINFO is
// defined, otherwise it is extracted from the macro parameter
//
@@ -52,17 +52,17 @@
* The second function
* \code static CppUnit::TestSuite *suite()\endcode
- * returns a pointer to the suite of tests defined by the CU_TEST()
+ * returns a pointer to the suite of tests defined by the CPPUNIT_TEST()
* macros.
*
@@ -52,17 +52,17 @@
*
* Rather than invoking suite() directly,
- * the macro CU_TEST_SUITE_REGISTRATION() is
+ * the macro CPPUNIT_TEST_SUITE_REGISTRATION() is
* used to create a static variable that automatically
* registers its test suite in a global registry.
@@ -93,13 +93,13 @@
*
* This macro starts the declaration of a new test suite.
- * Use CU_TEST_SUB_SUITE() instead, if you wish to include the
+ * Use CPPUNIT_TEST_SUB_SUITE() instead, if you wish to include the
* test suite of the parent class.
*
@@ -113,10 +113,10 @@
*
* This macro may only be used in a class whose parent class
- * defines a test suite using CU_TEST_SUITE() or CU_TEST_SUB_SUITE().
+ * defines a test suite using CPPUNIT_TEST_SUITE() or CPPUNIT_TEST_SUB_SUITE().
*
* This macro begins the declaration of a test suite, in the same
@@ -113,10 +113,10 @@
*
* This macro begins the declaration of a test suite, in the same
- * manner as CU_TEST_SUITE(). In addition, the test suite of the
+ * manner as CPPUNIT_TEST_SUITE(). In addition, the test suite of the
* parent is automatically inserted in the test suite being
* defined.